@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CopyJob.cc,v 1.43 2008/11/27 05:56:10 lav Exp $ */
+/* $Id: CopyJob.cc,v 1.44 2009/03/20 12:25:06 lav Exp $ */
 
 #include <config.h>
 #include "CopyJob.h"
@@ -148,27 +148,22 @@ CopyJob::CopyJob(FileCopy *c1,const char *name1,const char *op1)
 
 const char *CopyJob::FormatBytesTimeRate(off_t bytes,double time_spent)
 {
-   static char buf[256];
-
    if(bytes<=0)
       return "";
 
    if(time_spent>=1)
    {
-      sprintf(buf,plural("%lld $#ll#byte|bytes$ transferred"
-		     " in %ld $#l#second|seconds$",
+      xstring& msg=xstring::format(
+	 plural("%lld $#ll#byte|bytes$ transferred in %ld $#l#second|seconds$",
 		     (long long)bytes,long(time_spent+.5)),
 		     (long long)bytes,long(time_spent+.5));
       double rate=bytes/time_spent;
       if(rate>=1)
-	 sprintf(buf+strlen(buf)," (%s)",Speedometer::GetStr(rate));
+	 msg.appendf(" (%s)",Speedometer::GetStr(rate).get());
+      return msg;
    }
-   else
-   {
-      sprintf(buf,plural("%lld $#ll#byte|bytes$ transferred",
+   return xstring::format(plural("%lld $#ll#byte|bytes$ transferred",
 		     (long long)bytes),(long long)bytes);
-   }
-   return buf;
 }
 
 
