@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SleepJob.cc,v 1.40 2008/11/27 05:56:29 lav Exp $ */
+/* $Id: SleepJob.cc,v 1.41 2009/03/18 11:30:19 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -91,13 +91,32 @@ int SleepJob::Do()
    return STALL;
 }
 
+const char *SleepJob::Status()
+{
+   if(Stopped() || TimeLeft().Seconds()<=1)
+      return "";
+
+   if(IsInfty())
+      return(_("Sleeping forever"));
+   return xstring::cat(_("Sleep time left: "),
+      TimeLeft().toString(TimeInterval::TO_STR_TRANSLATE),
+      NULL);
+}
+
 void SleepJob::PrintStatus(int,const char *prefix)
 {
    if(repeat)
    {
       printf(_("\tRepeat count: %d\n"),repeat_count);
-      return;
    }
+   const char *s=Status();
+   if(s[0])
+      printf("\t%s\n",s);
+}
+void SleepJob::ShowRunStatus(const SMTaskRef<StatusLine>& s)
+{
+   s->Show(Status());
+   current->TimeoutS(1);
 }
 
 void SleepJob::lftpMovesToBackground()
